@@ -1,12 +1,9 @@
 # --
-# Kernel/GenericInterface/Debugger.pm - GenericInterface data debugger interface
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
-# --
-# $Id: Debugger.pm,v 1.17 2011-02-24 14:38:06 mg Exp $
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::GenericInterface::Debugger;
@@ -16,10 +13,7 @@ use warnings;
 
 use Kernel::System::VariableCheck qw(IsString IsStringWithData IsHashRefWithData);
 
-use Kernel::System::GenericInterface::DebugLog;
-
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.17 $) [1];
+our $ObjectManagerDisabled = 1;
 
 =head1 NAME
 
@@ -44,49 +38,13 @@ based on the configured debug level.
 
 create an object.
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
-    use Kernel::System::Time;
-    use Kernel::System::Main;
-    use Kernel::System::DB;
     use Kernel::GenericInterface::Debugger;
 
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
-    my $TimeObject = Kernel::System::Time->new(
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-    );
-    my $MainObject = Kernel::System::Main->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-    );
-    my $DBObject = Kernel::System::DB->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        MainObject   => $MainObject,
-    );
     my $DebuggerObject = Kernel::GenericInterface::Debugger->new(
-        ConfigObject       => $ConfigObject,
-        LogObject          => $LogObject,
-        DBObject           => $DBObject,
-        MainObject         => $MainObject,
-        TimeObject         => $TimeObject,
-        EncodeObject       => $EncodeObject,
-
         DebuggerConfig   => {
             DebugThreshold  => 'debug',
             TestMode        => 0,           # optional, in testing mode the data will not be written to the DB
-            ...
+            # ...
         },
 
         WebserviceID        => 12,
@@ -103,14 +61,13 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # check for needed object
-    for my $Needed (qw(MainObject ConfigObject LogObject EncodeObject TimeObject DBObject)) {
-        $Self->{$Needed} = $Param{$Needed} || die "Got no $Needed!";
-    }
-
     # check DebuggerConfig - we need a hash ref with at least one entry
     if ( !IsHashRefWithData( $Param{DebuggerConfig} ) ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need DebuggerConfig!' );
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'Need DebuggerConfig!',
+        );
+
         return;
     }
 
@@ -120,7 +77,11 @@ sub new {
     # check for mandatory values
     for my $Needed (qw(WebserviceID CommunicationType DebugThreshold)) {
         if ( !IsStringWithData( $Param{$Needed} ) ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "Need $Needed!"
+            );
+
             return;
         }
         $Self->{$Needed} = $Param{$Needed};
@@ -128,37 +89,45 @@ sub new {
 
     # check correct DebugThreshold
     if ( $Self->{DebugThreshold} !~ /^(debug|info|notice|error)/i ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'DebugThreshold is not allowed.' );
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'DebugThreshold is not allowed.',
+        );
+
         return;
     }
 
     # check correct CommunicationType
     if ( lc $Self->{CommunicationType} !~ /^(provider|requester)/i ) {
-        $Self->{LogObject}
-            ->Log( Priority => 'error', Message => 'CommunicationType is not allowed.' );
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'CommunicationType is not allowed.',
+        );
+
         return;
     }
 
     # TestMode
     $Self->{TestMode} = $Param{DebuggerConfig}->{TestMode} || 0;
 
-    # remote ip optional
+    # remote IP optional
     if ( defined $Param{RemoteIP} && !IsStringWithData( $Param{RemoteIP} ) ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need RemoteIP address!' );
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'Need RemoteIP address!'
+        );
+
         return;
     }
     $Self->{RemoteIP} = $Param{RemoteIP};
 
-    # comminication ID md5 (system time + random #)
-    my $CurrentTime = $Self->{TimeObject}->SystemTime();
-    my $MD5String   = $Self->{MainObject}->MD5sum(
+    # communication ID MD5 (system time + random #)
+    my $CurrentTime = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
+    my $MD5String   = $Kernel::OM->Get('Kernel::System::Main')->MD5sum(
         String => $CurrentTime . int( rand(1000000) ),
     );
     $Self->{CommunicationID} = $MD5String;
 
-    # create DebugLog object
-    $Self->{DebugLogObject} = Kernel::System::GenericInterface::DebugLog->new( %{$Self} );
-
     return $Self;
 }
 
@@ -181,7 +150,11 @@ sub DebugLog {
     my ( $Self, %Param ) = @_;
 
     if ( !$Param{Summary} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need Summary!' );
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'Need Summary!',
+        );
+
         return;
     }
 
@@ -190,7 +163,11 @@ sub DebugLog {
 
     # check correct DebugLevel
     if ( $Param{DebugLevel} !~ /^(debug|info|notice|error)/i ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'DebugLevel is not allowed.' );
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'DebugLevel is not allowed.',
+        );
+
         return;
     }
     my %DebugLevels = (
@@ -203,7 +180,7 @@ sub DebugLog {
     # create log message
     my $DataString = '';
     if ( IsHashRefWithData( $Param{Data} ) ) {
-        $DataString = $Self->{MainObject}->Dump( $Param{Data} );
+        $DataString = $Kernel::OM->Get('Kernel::System::Main')->Dump( $Param{Data} );
     }
     elsif ( IsStringWithData( $Param{Data} ) ) {
         $DataString = $Param{Data};
@@ -217,7 +194,7 @@ sub DebugLog {
         if ( $DebugLevels{ $Param{DebugLevel} } >= $DebugLevels{ $Self->{DebugThreshold} } ) {
 
             # call AddLog function
-            $Self->{DebugLogObject}->LogAdd(
+            $Kernel::OM->Get('Kernel::System::GenericInterface::DebugLog')->LogAdd(
                 CommunicationID   => $Self->{CommunicationID},
                 CommunicationType => $Self->{CommunicationType},
                 RemoteIP          => $Self->{RemoteIP},
@@ -238,7 +215,7 @@ EOF
 
     if ( $Param{DebugLevel} eq 'error' ) {
         $LogMessage =~ s/\n//g;
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => $LogMessage,
         );
@@ -354,7 +331,7 @@ destructor, this will write the log entries to the database.
 =cut
 
 sub DESTROY {
-    my ($Self) = @_;
+    my $Self = shift;
 
     #TODO: implement storing of the debug messages
 
@@ -368,16 +345,10 @@ sub DESTROY {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<http://otrs.org/>).
+This software is part of the OTRS project (L<https://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
-
-=cut
-
-=head1 VERSION
-
-$Revision: 1.17 $ $Date: 2011-02-24 14:38:06 $
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
 
 =cut
