@@ -1,10 +1,9 @@
 # --
-# Kernel/Modules/AdminPackageManager.pm - manage software packages
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::Modules::AdminPackageManager;
@@ -1312,6 +1311,7 @@ sub Run {
     $Frontend{SourceList} = $Self->{LayoutObject}->BuildSelection(
         Data        => { %List, %RepositoryRoot, %{$RepositoryCloudList}, },
         Name        => 'Source',
+        Title       => 'Repository List',
         Max         => 40,
         Translation => 0,
         SelectedID  => $Source,
@@ -1401,7 +1401,12 @@ sub Run {
 
     # remove not visible packages
     @RepositoryList = map {
-        ( !defined $_->{PackageIsVisible} || $_->{PackageIsVisible}->{Content} eq '1' ) ? $_ : ()
+        (
+            !defined $_->{PackageIsVisible}
+                || ( $_->{PackageIsVisible}->{Content} && $_->{PackageIsVisible}->{Content} eq '1' )
+            )
+            ? $_
+            : ()
     } @RepositoryList;
 
     # if there are no local packages to show, a msg is displayed
