@@ -1,10 +1,9 @@
 # --
-# Kernel/Modules/AdminRegistration.pm - to register the OTRS system
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::Modules::AdminRegistration;
@@ -16,6 +15,9 @@ use Kernel::System::Environment;
 use Kernel::System::Registration;
 use Kernel::System::SystemData;
 use Kernel::System::OTRSBusiness;
+use Kernel::System::PID;
+
+our $ObjectManagerDisabled = 1;
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -34,6 +36,7 @@ sub new {
     $Self->{RegistrationObject} = Kernel::System::Registration->new(%Param);
     $Self->{SystemDataObject}   = Kernel::System::SystemData->new(%Param);
     $Self->{OTRSBusinessObject} = Kernel::System::OTRSBusiness->new(%Param);
+    $Self->{PIDObject}          = Kernel::System::PID->new(%Param);
 
     $Self->{RegistrationState} = $Self->{SystemDataObject}->SystemDataGet(
         Key => 'Registration::State',
@@ -56,11 +59,42 @@ sub Run {
         }
     }
 
+    # ------------------------------------------------------------ #
+    # Scheduler not running screen
+    # ------------------------------------------------------------ #
+    if (
+        $Self->{Subaction} ne 'OTRSIDValidate'
+        && $Self->{RegistrationState} ne 'registered'
+        && !$Self->_SchedulerRunning()
+        )
+    {
+
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+
+        $Self->{LayoutObject}->Block(
+            Name => 'Overview',
+            Data => \%Param,
+        );
+
+        $Self->{LayoutObject}->Block(
+            Name => 'SchedulerNotRunning',
+        );
+
+        $Output .= $Self->{LayoutObject}->Output(
+            TemplateFile => 'AdminRegistration',
+            Data         => \%Param,
+        );
+        $Output .= $Self->{LayoutObject}->Footer();
+
+        return $Output;
+    }
+
     # ------------------------------------------------------------ #
     # check OTRS ID
     # ------------------------------------------------------------ #
 
-    if ( $Self->{Subaction} eq 'CheckOTRSID' ) {
+    elsif ( $Self->{Subaction} eq 'CheckOTRSID' ) {
 
         my $OTRSID   = $Self->{ParamObject}->GetParam( Param => 'OTRSID' )   || '';
         my $Password = $Self->{ParamObject}->GetParam( Param => 'Password' ) || '';
@@ -85,7 +119,7 @@ sub Run {
         my %Result = (
             Success => $Response{Success} ? 'OK' : 'False',
             Message => $Response{Reason} || '',
-            Token   => $Response{Token}  || '',
+            Token   => $Response{Token} || '',
         );
 
         my $Output = $Self->{LayoutObject}->Header();
@@ -106,6 +140,11 @@ sub Run {
             Data => \%Param,
         );
 
+        $Self->{LayoutObject}->Block(
+            Name => 'OTRSIDValidationForm',
+            Data => \%Param,
+        );
+
         my $Block = $Self->{RegistrationState} ne 'registered'
             ? 'OTRSIDRegistration'
             : 'OTRSIDDeregistration';
@@ -135,14 +174,21 @@ sub Run {
             Data => \%Param,
         );
 
-        my $EntitlementStatus = $Self->{OTRSBusinessObject}->OTRSBusinessEntitlementStatus(
-            CallCloudService => 1,
-        );
+        my $EntitlementStatus = 'forbidden';
+        if ( $Self->{RegistrationState} eq 'registered' ) {
+
+            # Only call cloud service for a registered system
+            $EntitlementStatus = $Self->{OTRSBusinessObject}->OTRSBusinessEntitlementStatus(
+                CallCloudService => 1,
+            );
+        }
 
         # users should not be able to de-register their system if they either have
         # OTRS Business Solution installed or are entitled to use it (by having a valid contract).
-        if ( $Self->{RegistrationState} eq 'registered'
-            && ( $Self->{OTRSBusinessObject}->OTRSBusinessIsInstalled() || $EntitlementStatus ne 'forbidden' ) )
+        if (
+            $Self->{RegistrationState} eq 'registered'
+            && ( $Self->{OTRSBusinessObject}->OTRSBusinessIsInstalled() || $EntitlementStatus ne 'forbidden' )
+            )
         {
 
             $Self->{LayoutObject}->Block( Name => 'ActionList' );
@@ -159,9 +205,22 @@ sub Run {
                 Data => \%Param,
             );
 
-            my $Block = $Self->{RegistrationState} ne 'registered'
-                ? 'OTRSIDRegistration'
-                : 'OTRSIDDeregistration';
+            # check if the scheduler is not running
+            if ( $Self->{RegistrationState} ne 'registered' && !$Self->_SchedulerRunning() ) {
+
+                $Self->{LayoutObject}->Block(
+                    Name => 'OTRSIDValidationSchedulerNotRunning',
+                );
+            }
+            else {
+
+                $Self->{LayoutObject}->Block(
+                    Name => 'OTRSIDValidationForm',
+                    Data => \%Param,
+                );
+            }
+
+            my $Block = $Self->{RegistrationState} ne 'registered' ? 'OTRSIDRegistration' : 'OTRSIDDeregistration';
             $Self->{LayoutObject}->Block(
                 Name => $Block,
             );
@@ -415,6 +474,13 @@ sub Run {
         );
     }
 
+    # ------------------------------------------------------------ #
+    # sent data overview
+    # ------------------------------------------------------------ #
+    elsif ( $Self->{Subaction} eq 'SentDataOverview' ) {
+        return $Self->_SentDataOverview();
+    }
+
     # ------------------------------------------------------------
     # overview
     # ------------------------------------------------------------
@@ -469,6 +535,7 @@ sub _Overview {
 
     $Self->{LayoutObject}->Block( Name => 'ActionList' );
     $Self->{LayoutObject}->Block( Name => 'ActionUpdate' );
+    $Self->{LayoutObject}->Block( Name => 'ActionSentDataOverview' );
     $Self->{LayoutObject}->Block( Name => 'ActionDeregister' );
 
     $Self->{LayoutObject}->Block(
@@ -479,4 +546,83 @@ sub _Overview {
     return 1;
 }
 
+sub _SentDataOverview {
+    my ( $Self, %Param ) = @_;
+
+    my $Output = $Self->{LayoutObject}->Header();
+    $Output .= $Self->{LayoutObject}->NavigationBar();
+
+    $Self->{LayoutObject}->Block(
+        Name => 'Overview',
+        Data => \%Param,
+    );
+
+    $Self->{LayoutObject}->Block( Name => 'ActionList' );
+    $Self->{LayoutObject}->Block( Name => 'ActionOverview' );
+
+    my %RegistrationData = $Self->{RegistrationObject}->RegistrationDataGet();
+
+    $Self->{LayoutObject}->Block(
+        Name => 'SentDataOverview',
+    );
+
+    if ( $Self->{RegistrationState} ne 'registered' ) {
+        $Self->{LayoutObject}->Block( Name => 'SentDataOverviewNoData' );
+    }
+    else {
+        my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+        my %OSInfo       = $Kernel::OM->Get('Kernel::System::Environment')->OSInfoGet();
+        my %System       = (
+            PerlVersion        => sprintf( "%vd", $^V ),
+            OSType             => $OSInfo{OS},
+            OSVersion          => $OSInfo{OSName},
+            OTRSVersion        => $ConfigObject->Get('Version'),
+            FQDN               => $ConfigObject->Get('FQDN'),
+            DatabaseVersion    => $Kernel::OM->Get('Kernel::System::DB')->Version(),
+            SupportDataSending => $Param{SupportDataSending} || $RegistrationData{SupportDataSending} || 'No',
+        );
+        my $RegistrationUpdateDataDump = $Kernel::OM->Get('Kernel::System::Main')->Dump( \%System );
+
+        my $SupportDataDump;
+        if ( $System{SupportDataSending} eq 'Yes' ) {
+            my %SupportData = $Kernel::OM->Get('Kernel::System::SupportDataCollector')->Collect();
+            $SupportDataDump = $Kernel::OM->Get('Kernel::System::Main')->Dump( $SupportData{Result} );
+        }
+
+        $Self->{LayoutObject}->Block(
+            Name => 'SentDataOverviewData',
+            Data => {
+                RegistrationUpdate => $RegistrationUpdateDataDump,
+                SupportData        => $SupportDataDump,
+            },
+        );
+    }
+
+    $Output .= $Self->{LayoutObject}->Output(
+        TemplateFile => 'AdminRegistration',
+        Data         => \%Param,
+    );
+    $Output .= $Self->{LayoutObject}->Footer();
+
+    return $Output;
+}
+
+sub _SchedulerRunning {
+    my ( $Self, %Param ) = @_;
+
+    # try to get scheduler PID
+    my %PID = $Self->{PIDObject}->PIDGet(
+        Name => 'otrs.Scheduler',
+    );
+
+    my $PIDUpdateTime = $Self->{ConfigObject}->Get('Scheduler::PIDUpdateTime') || 600;
+
+    # check if scheduler process is registered in the DB and if the update was not too long ago
+    if ( !%PID || ( time() - $PID{Changed} > 4 * $PIDUpdateTime ) ) {
+        return;
+    }
+
+    return 1;
+}
+
 1;
