@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::Output::HTML::LayoutTicket;
@@ -118,7 +118,11 @@ sub AgentCustomerViewTable {
             );
             if (
                 $Field->[6]
-                && ( $Param{Data}->{TicketID} || $Param{Ticket} )
+                && (
+                    $Param{Data}->{TicketID}
+                    || $Param{Ticket}
+                    || $Field->[6] !~ m{Env\("CGIHandle"\)}
+                )
                 )
             {
                 $Record{LinkStart} = "<a href=\"$Field->[6]\"";
@@ -1242,10 +1246,10 @@ sub TicketMetaItems {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<http://otrs.org/>).
+This software is part of the OTRS project (L<https://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
 
 =cut
