@@ -1,10 +1,9 @@
 # --
-# Kernel/Output/HTML/ToolBarGeneric.pm
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::Output::HTML::ToolBarGeneric;
@@ -32,6 +31,13 @@ sub Run {
 
     my $Priority = $Param{Config}->{'Priority'};
     my %Return   = ();
+
+    # check if there is extended data available
+    my %Data;
+    if ( $Param{Config}->{Data} && %{ $Param{Config}->{Data} } ) {
+        %Data = %{ $Param{Config}->{Data} };
+    }
+
     $Return{ $Priority++ } = {
         Block       => $Param{Config}->{Block},
         Description => $Param{Config}->{Description},
@@ -40,6 +46,7 @@ sub Run {
         Fulltext    => '',
         Image       => '',
         AccessKey   => '',
+        %Data,
     };
     return %Return;
 }
