@@ -1,10 +1,9 @@
 # --
-# Kernel/System/AuthSession/DB.pm - provides session db backend
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::System::AuthSession::DB;
@@ -31,17 +30,7 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get config object
-    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
-
-    # get more common params
-    $Self->{SessionTable}                = $ConfigObject->Get('SessionTable') || 'sessions';
-    $Self->{SystemID}                    = $ConfigObject->Get('SystemID');
-    $Self->{AgentSessionLimit}           = $ConfigObject->Get('AgentSessionLimit');
-    $Self->{AgentSessionPerUserLimit}    = $ConfigObject->Get('AgentSessionPerUserLimit');
-    $Self->{CustomerSessionLimit}        = $ConfigObject->Get('CustomerSessionLimit');
-    $Self->{CustomerSessionPerUserLimit} = $ConfigObject->Get('CustomerSessionPerUserLimit');
-    $Self->{SessionActiveTime}           = $ConfigObject->Get('SessionActiveTime') || 60 * 10;
+    $Self->{SessionTable} = $Kernel::OM->Get('Kernel::Config')->Get('SessionTable') || 'sessions';
 
     # get database type
     $Self->{DBType} = $Kernel::OM->Get('Kernel::System::DB')->{'DB::Type'} || '';
@@ -232,102 +221,8 @@ sub GetSessionIDData {
 sub CreateSessionID {
     my ( $Self, %Param ) = @_;
 
-    # get system time
     my $TimeNow = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
 
-    # get session limit config
-    my $SessionLimit;
-    if ( $Param{UserType} && $Param{UserType} eq 'User' && $Self->{AgentSessionLimit} ) {
-        $SessionLimit = $Self->{AgentSessionLimit};
-    }
-    elsif ( $Param{UserType} && $Param{UserType} eq 'Customer' && $Self->{CustomerSessionLimit} ) {
-        $SessionLimit = $Self->{CustomerSessionLimit};
-    }
-
-    # get session per user limit config
-    my $SessionPerUserLimit;
-    if ( $Param{UserType} && $Param{UserType} eq 'User' && $Self->{AgentSessionPerUserLimit} ) {
-        $SessionPerUserLimit = $Self->{AgentSessionPerUserLimit};
-    }
-    elsif (
-        $Param{UserType}
-        && $Param{UserType} eq 'Customer'
-        && $Self->{CustomerSessionPerUserLimit}
-        )
-    {
-        $SessionPerUserLimit = $Self->{CustomerSessionPerUserLimit};
-    }
-
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
-    if ( $SessionLimit || $SessionPerUserLimit ) {
-
-        # get all needed timestamps to investigate the expired sessions
-        $DBObject->Prepare(
-            SQL => "
-                SELECT session_id, data_key, data_value
-                FROM $Self->{SessionTable}
-                WHERE data_key = 'UserType'
-                    OR data_key = 'UserLastRequest'
-                    OR data_key = 'UserLogin'
-                ORDER BY id ASC",
-        );
-
-        my %SessionData;
-        ROW:
-        while ( my @Row = $DBObject->FetchrowArray() ) {
-
-            next ROW if !$Row[0];
-            next ROW if !$Row[1];
-
-            $SessionData{ $Row[0] }->{ $Row[1] } = $Row[2];
-        }
-
-        my $ActiveSessionCount = 0;
-        my %ActiveSessionPerUserCount;
-        SESSIONID:
-        for my $SessionID ( sort keys %SessionData ) {
-
-            next SESSIONID if !$SessionID;
-            next SESSIONID if !$SessionData{$SessionID};
-
-            # get needed data
-            my $UserType        = $SessionData{$SessionID}->{UserType}        || '';
-            my $UserLastRequest = $SessionData{$SessionID}->{UserLastRequest} || $TimeNow;
-            my $UserLogin       = $SessionData{$SessionID}->{UserLogin};
-
-            next SESSIONID if $UserType ne $Param{UserType};
-
-            next SESSIONID if ( $UserLastRequest + $Self->{SessionActiveTime} ) < $TimeNow;
-
-            $ActiveSessionCount++;
-
-            $ActiveSessionPerUserCount{$UserLogin} || 0;
-            $ActiveSessionPerUserCount{$UserLogin}++;
-
-            next SESSIONID if $ActiveSessionCount < $SessionLimit;
-
-            $Self->{SessionIDErrorMessage} = 'Session limit reached! Please try again later.';
-
-            return;
-        }
-
-        # check session per user limit
-        if (
-            $SessionPerUserLimit
-            && $Param{UserLogin}
-            && defined $ActiveSessionPerUserCount{ $Param{UserLogin} }
-            && $ActiveSessionPerUserCount{ $Param{UserLogin} } >= $SessionPerUserLimit
-            )
-        {
-
-            $Self->{SessionIDErrorMessage} = 'Session per user limit reached!';
-
-            return;
-        }
-    }
-
     # get remote address and the http user agent
     my $RemoteAddr      = $ENV{REMOTE_ADDR}     || 'none';
     my $RemoteUserAgent = $ENV{HTTP_USER_AGENT} || 'none';
@@ -359,6 +254,8 @@ sub CreateSessionID {
     $Data{UserRemoteUserAgent} = $RemoteUserAgent;
     $Data{UserChallengeToken}  = $ChallengeToken;
 
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # create sql data
     my @SQLs;
     $Self->_SQLCreate(
@@ -479,6 +376,73 @@ sub GetAllSessionIDs {
     return @SessionIDs;
 }
 
+sub GetActiveSessions {
+    my ( $Self, %Param ) = @_;
+
+    my $MaxSessionIdleTime = $Kernel::OM->Get('Kernel::Config')->Get('SessionMaxIdleTime');
+
+    # get system time
+    my $TimeNow = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
+
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    $DBObject->Prepare(
+        SQL => "
+            SELECT session_id, data_key, data_value
+            FROM $Self->{SessionTable}
+            WHERE data_key = 'UserType'
+                OR data_key = 'UserLastRequest'
+                OR data_key = 'UserLogin'
+                OR data_key = 'SessionSource'
+            ORDER BY id ASC",
+    );
+
+    my %SessionData;
+    ROW:
+    while ( my @Row = $DBObject->FetchrowArray() ) {
+
+        next ROW if !$Row[0];
+        next ROW if !$Row[1];
+
+        $SessionData{ $Row[0] }->{ $Row[1] } = $Row[2];
+    }
+
+    my $ActiveSessionCount = 0;
+    my %ActiveSessionPerUserCount;
+    SESSIONID:
+    for my $SessionID ( sort keys %SessionData ) {
+
+        next SESSIONID if !$SessionID;
+        next SESSIONID if !$SessionData{$SessionID};
+
+        # Don't count session from source 'GenericInterface'
+        my $SessionSource = $SessionData{$SessionID}->{SessionSource} || '';
+
+        next SESSIONID if $SessionSource eq 'GenericInterface';
+
+        # get needed data
+        my $UserType        = $SessionData{$SessionID}->{UserType}        || '';
+        my $UserLastRequest = $SessionData{$SessionID}->{UserLastRequest} || $TimeNow;
+        my $UserLogin       = $SessionData{$SessionID}->{UserLogin};
+
+        next SESSIONID if $UserType ne $Param{UserType};
+
+        next SESSIONID if ( $UserLastRequest + $MaxSessionIdleTime ) < $TimeNow;
+
+        $ActiveSessionCount++;
+
+        $ActiveSessionPerUserCount{$UserLogin} || 0;
+        $ActiveSessionPerUserCount{$UserLogin}++;
+    }
+
+    my %Result = (
+        Total   => $ActiveSessionCount,
+        PerUser => \%ActiveSessionPerUserCount,
+    );
+
+    return %Result;
+}
+
 sub GetExpiredSessionIDs {
     my ( $Self, %Param ) = @_;
 
