@@ -1,10 +1,9 @@
 # --
-# Kernel/System/GenericInterface/ObjectLockState.pm - backend for lock state handling
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::System::GenericInterface::ObjectLockState;
@@ -12,6 +11,11 @@ package Kernel::System::GenericInterface::ObjectLockState;
 use strict;
 use warnings;
 
+our @ObjectDependencies = (
+    'Kernel::System::DB',
+    'Kernel::System::Log',
+);
+
 =head1 NAME
 
 Kernel::System::GenericInterface::ObjectLockState - lock state backend
@@ -26,47 +30,11 @@ Kernel::System::GenericInterface::ObjectLockState - lock state backend
 
 =item new()
 
-create an object
+create a debug log object. Do not use it directly, instead use:
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
-    use Kernel::System::Time;
-    use Kernel::System::Main;
-    use Kernel::System::DB;
-    use Kernel::System::GenericInterface::ObjectLockState;
-
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
-    my $TimeObject = Kernel::System::Time->new(
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-    );
-    my $MainObject = Kernel::System::Main->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-    );
-    my $DBObject = Kernel::System::DB->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        MainObject   => $MainObject,
-    );
-    my $ObjectLockStateObject = Kernel::System::GenericInterface::ObjectLockState->new(
-        ConfigObject   => $ConfigObject,
-        LogObject      => $LogObject,
-        DBObject       => $DBObject,
-        MainObject     => $MainObject,
-        TimeObject     => $TimeObject,
-        EncodeObject   => $EncodeObject,
-    );
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
+    my $ObjectLockStateObject = $Kernel::OM->Get('Kernel::System::GenericInterface::ObjectLockState');
 
 =cut
 
@@ -77,11 +45,6 @@ sub new {
     my $Self = {};
     bless( $Self, $ObjectLockState );
 
-    # check needed objects
-    for my $Object (qw(DBObject ConfigObject LogObject MainObject EncodeObject TimeObject)) {
-        $Self->{$Object} = $Param{$Object} || die "Got no $Object!";
-    }
-
     return $Self;
 }
 
@@ -105,7 +68,7 @@ sub ObjectLockStateSet {
     # check needed stuff
     for my $Key (qw(WebserviceID ObjectType ObjectID LockState)) {
         if ( !$Param{$Key} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Key!"
             );
@@ -113,9 +76,12 @@ sub ObjectLockStateSet {
         }
     }
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # create new
     if ( !%{ $Self->ObjectLockStateGet(%Param) || {} } ) {
-        return if !$Self->{DBObject}->Do(
+        return if !$DBObject->Do(
             SQL => '
                 INSERT INTO gi_object_lock_state
                     (webservice_id, object_type, object_id, lock_state, lock_state_counter, create_time, change_time)
@@ -131,7 +97,7 @@ sub ObjectLockStateSet {
     }
     else {    # update existing
 
-        return if !$Self->{DBObject}->Do(
+        return if !$DBObject->Do(
             SQL => '
                 UPDATE gi_object_lock_state
                 SET lock_state = ?, lock_state_counter = ?, change_time = current_timestamp
@@ -184,7 +150,7 @@ sub ObjectLockStateGet {
     # check needed stuff
     for my $Key (qw(WebserviceID ObjectType ObjectID)) {
         if ( !$Param{$Key} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Key!"
             );
@@ -192,7 +158,10 @@ sub ObjectLockStateGet {
         }
     }
 
-    return if !$Self->{DBObject}->Prepare(
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Prepare(
         SQL => '
             SELECT webservice_id, object_type, object_id, lock_state, lock_state_counter, create_time, change_time
             FROM gi_object_lock_state
@@ -207,8 +176,7 @@ sub ObjectLockStateGet {
     );
 
     my %Result;
-
-    while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Data = $DBObject->FetchrowArray() ) {
 
         %Result = (
             WebserviceID     => $Data[0],
@@ -242,7 +210,7 @@ sub ObjectLockStateDelete {
     # check needed stuff
     for my $Key (qw(WebserviceID ObjectType ObjectID)) {
         if ( !$Param{$Key} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Key!"
             );
@@ -252,7 +220,10 @@ sub ObjectLockStateDelete {
 
     return if ( !%{ $Self->ObjectLockStateGet(%Param) || {} } );
 
-    return if !$Self->{DBObject}->Do(
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Do(
         SQL => '
             DELETE FROM gi_object_lock_state
             WHERE webservice_id = ?
@@ -284,7 +255,7 @@ sub ObjectLockStatePurge {
     # check needed stuff
     for my $Key (qw(WebserviceID)) {
         if ( !$Param{$Key} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Key!"
             );
@@ -292,7 +263,10 @@ sub ObjectLockStatePurge {
         }
     }
 
-    return if !$Self->{DBObject}->Do(
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Do(
         SQL => '
             DELETE FROM gi_object_lock_state
             WHERE webservice_id = ?',
@@ -337,7 +311,7 @@ sub ObjectLockStateList {
     # check needed stuff
     for my $Key (qw(ObjectType)) {
         if ( !$Param{$Key} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Key!"
             );
@@ -365,14 +339,17 @@ sub ObjectLockStateList {
 
     $SQL .= ' ORDER BY object_id ASC';
 
-    return if !$Self->{DBObject}->Prepare(
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Prepare(
         SQL  => $SQL,
         Bind => \@Bind,
     );
 
     my @Result;
 
-    while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Data = $DBObject->FetchrowArray() ) {
 
         push @Result, {
             WebserviceID     => $Data[0],
@@ -394,10 +371,10 @@ sub ObjectLockStateList {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<http://otrs.org/>).
+This software is part of the OTRS project (L<https://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
 
 =cut
