@@ -1,19 +1,26 @@
 # --
-# Kernel/System/MailAccount/POP3.pm - lib for pop3 accounts
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::System::MailAccount::POP3;
 
 use strict;
 use warnings;
+
 use Net::POP3;
+
 use Kernel::System::PostMaster;
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::Log',
+    'Kernel::System::Main',
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -21,11 +28,6 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
-    # check all needed objects
-    for (qw(DBObject LogObject ConfigObject TimeObject MainObject)) {
-        die "Got no $_" if !$Self->{$_};
-    }
-
     # reset limit
     $Self->{Limit} = 0;
 
@@ -38,7 +40,7 @@ sub Connect {
     # check needed stuff
     for (qw(Login Password Host Timeout Debug)) {
         if ( !defined $Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -96,7 +98,7 @@ sub Fetch {
     # check needed stuff
     for (qw(Login Password Host Trusted QueueID)) {
         if ( !defined $Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "$_ not defined!"
             );
@@ -105,7 +107,7 @@ sub Fetch {
     }
     for (qw(Login Password Host)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -117,11 +119,14 @@ sub Fetch {
     my $Limit = $Param{Limit} || 5000;
     my $CMD   = $Param{CMD}   || 0;
 
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     # MaxEmailSize
-    my $MaxEmailSize = $Self->{ConfigObject}->Get('PostMasterMaxEmailSize') || 1024 * 6;
+    my $MaxEmailSize = $ConfigObject->Get('PostMasterMaxEmailSize') || 1024 * 6;
 
     # MaxPopEmailSession
-    my $MaxPopEmailSession = $Self->{ConfigObject}->Get('PostMasterReconnectMessage') || 20;
+    my $MaxPopEmailSession = $ConfigObject->Get('PostMasterReconnectMessage') || 20;
 
     my $FetchCounter = 0;
 
@@ -136,7 +141,7 @@ sub Fetch {
     );
 
     if ( !$Connect{Successful} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "$Connect{Message}",
         );
@@ -154,6 +159,7 @@ sub Fetch {
     }
     else {
         my $MessageList = $PopObject->list();
+        MESSAGE_NO:
         for my $Messageno ( sort keys %{$MessageList} ) {
 
             # check if reconnect is needed
@@ -162,7 +168,7 @@ sub Fetch {
                 if ($CMD) {
                     print "$AuthType: Reconnect Session after $MaxPopEmailSession messages...\n";
                 }
-                last;
+                last MESSAGE_NO;
             }
             if ($CMD) {
                 print "$AuthType: Message $Messageno/$NOM ($Param{Login}/$Param{Host})\n";
@@ -173,7 +179,7 @@ sub Fetch {
 
                 # convert size to KB, log error
                 my $MessageSizeKB = int( $MessageList->{$Messageno} / (1024) );
-                $Self->{LogObject}->Log(
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'error',
                     Message  => "$AuthType: Can't fetch email $NOM from $Param{Login}/$Param{Host}. "
                         . "Email too big ($MessageSizeKB KB - max $MaxEmailSize KB)!",
@@ -183,18 +189,16 @@ sub Fetch {
 
                 # safety protection
                 $FetchCounter++;
-                if ( $FetchCounter > 10 ) {
-                    if ($CMD) {
-                        print
-                            "$AuthType: Safety protection: waiting 2 second before processing next mail...\n";
-                    }
-                    sleep 2;
+                my $FetchDelay = ( $FetchCounter % 20 == 0 ? 1 : 0 );
+                if ( $FetchDelay && $CMD ) {
+                    print "$AuthType: Safety protection: waiting 1 second before processing next mail...\n";
+                    sleep 1;
                 }
 
                 # get message (header and body)
                 my $Lines = $PopObject->get($Messageno);
                 if ( !$Lines ) {
-                    $Self->{LogObject}->Log(
+                    $Kernel::OM->Get('Kernel::System::Log')->Log(
                         Priority => 'error',
                         Message  => "$AuthType: Can't process mail, email no $Messageno is empty!",
                     );
@@ -209,7 +213,7 @@ sub Fetch {
                     my @Return = $PostMasterObject->Run( QueueID => $Param{QueueID} || 0 );
                     if ( !$Return[0] ) {
                         my $File = $Self->_ProcessFailed( Email => $Lines );
-                        $Self->{LogObject}->Log(
+                        $Kernel::OM->Get('Kernel::System::Log')->Log(
                             Priority => 'error',
                             Message  => "$AuthType: Can't process mail, mail saved ("
                                 . "$File, report it on http://bugs.otrs.org/)!",
@@ -225,7 +229,7 @@ sub Fetch {
                 $Self->{Limit}++;
                 if ( $Self->{Limit} >= $Limit ) {
                     $Self->{Reconnect} = 0;
-                    last;
+                    last MESSAGE_NO;
                 }
 
             }
@@ -237,7 +241,7 @@ sub Fetch {
 
     # log status
     if ( $Debug > 0 || $FetchCounter ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'info',
             Message  => "$AuthType: Fetched $FetchCounter email(s) from $Param{Login}/$Param{Host}.",
         );
@@ -256,7 +260,7 @@ sub _ProcessFailed {
 
     # check needed stuff
     if ( !defined $Param{Email} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "'Email' not defined!"
         );
@@ -269,13 +273,16 @@ sub _ProcessFailed {
         $Content .= $Line;
     }
 
-    my $Home = $Self->{ConfigObject}->Get('Home') . '/var/spool/';
-    my $MD5  = $Self->{MainObject}->MD5sum(
+    # get main object
+    my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
+
+    my $Home = $Kernel::OM->Get('Kernel::Config')->Get('Home') . '/var/spool/';
+    my $MD5  = $MainObject->MD5sum(
         String => \$Content,
     );
     my $Location = $Home . 'problem-email-' . $MD5;
 
-    return $Self->{MainObject}->FileWrite(
+    return $MainObject->FileWrite(
         Location   => $Location,
         Content    => \$Content,
         Mode       => 'binmode',
