@@ -1,10 +1,9 @@
 # --
-# Kernel/System/PostMaster.pm - the global PostMaster module for OTRS
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::System::PostMaster;
@@ -13,14 +12,20 @@ use strict;
 use warnings;
 
 use Kernel::System::EmailParser;
-use Kernel::System::Ticket;
-use Kernel::System::Queue;
-use Kernel::System::State;
-use Kernel::System::Priority;
-use Kernel::System::PostMaster::Reject;
-use Kernel::System::PostMaster::FollowUp;
-use Kernel::System::PostMaster::NewTicket;
 use Kernel::System::PostMaster::DestQueue;
+use Kernel::System::PostMaster::NewTicket;
+use Kernel::System::PostMaster::FollowUp;
+use Kernel::System::PostMaster::Reject;
+
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::DynamicField',
+    'Kernel::System::Log',
+    'Kernel::System::Main',
+    'Kernel::System::Queue',
+    'Kernel::System::State',
+    'Kernel::System::Ticket',
+);
 
 =head1 NAME
 
@@ -38,49 +43,16 @@ All postmaster functions. E. g. to process emails.
 
 =item new()
 
-create an object
+create an object. Do not use it directly, instead use:
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
-    use Kernel::System::Time;
-    use Kernel::System::Main;
-    use Kernel::System::DB;
-    use Kernel::System::PostMaster;
-
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
-    my $TimeObject = Kernel::System::Time->new(
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-    );
-    my $MainObject = Kernel::System::Main->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-    );
-    my $DBObject = Kernel::System::DB->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        MainObject   => $MainObject,
-    );
-    my $PostMasterObject = Kernel::System::PostMaster->new(
-        DBObject     => DBObject,
-        TimeObject   => TimeObject,
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        MainObject   => $MainObject,
-        LogObject    => $LogObject,
-        Email        => \@ArrayOfEmailContent,
-        Trusted      => 1, # 1|0 ignore X-OTRS header if false
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new(
+        'Kernel::System::PostMaster' => {
+            Email        => \@ArrayOfEmailContent,
+            Trusted      => 1, # 1|0 ignore X-OTRS header if false
+        },
     );
+    my $PostMasterObject = $Kernel::OM->Get('Kernel::System::PostMaster');
 
 =cut
 
@@ -92,52 +64,27 @@ sub new {
     bless( $Self, $Type );
 
     # check needed objects
-    for (qw(DBObject LogObject ConfigObject TimeObject MainObject EncodeObject Email)) {
-        $Self->{$_} = $Param{$_} || die "Got no $_!";
-    }
+    $Self->{Email} = $Param{Email} || die "Got no Email!";
 
     # for debug 0=off; 1=info; 2=on; 3=with GetHeaderParam;
     $Self->{Debug} = $Param{Debug} || 0;
 
-    # create common objects
-    $Self->{TicketObject} = Kernel::System::Ticket->new( %{$Self} );
     $Self->{ParserObject} = Kernel::System::EmailParser->new(
         Email => $Param{Email},
-        %Param,
-    );
-    $Self->{QueueObject}     = Kernel::System::Queue->new( %{$Self} );
-    $Self->{StateObject}     = Kernel::System::State->new( %{$Self} );
-    $Self->{PriorityObject}  = Kernel::System::Priority->new( %{$Self} );
-    $Self->{DestQueueObject} = Kernel::System::PostMaster::DestQueue->new(
-        %{$Self},
-        QueueObject  => $Self->{QueueObject},
-        ParserObject => $Self->{ParserObject},
-    );
-    $Self->{NewTicket} = Kernel::System::PostMaster::NewTicket->new(
-        %{$Self},
-        Debug          => $Self->{Debug},
-        ParserObject   => $Self->{ParserObject},
-        TicketObject   => $Self->{TicketObject},
-        QueueObject    => $Self->{QueueObject},
-        StateObject    => $Self->{StateObject},
-        PriorityObject => $Self->{PriorityObject},
-    );
-    $Self->{FollowUp} = Kernel::System::PostMaster::FollowUp->new(
-        %{$Self},
-        Debug        => $Self->{Debug},
-        TicketObject => $Self->{TicketObject},
-        ParserObject => $Self->{ParserObject},
-    );
-    $Self->{Reject} = Kernel::System::PostMaster::Reject->new(
-        %{$Self},
-        Debug        => $Self->{Debug},
-        TicketObject => $Self->{TicketObject},
-        ParserObject => $Self->{ParserObject},
     );
 
+    # create needed objects
+    $Self->{DestQueueObject} = Kernel::System::PostMaster::DestQueue->new( %{$Self} );
+    $Self->{NewTicketObject} = Kernel::System::PostMaster::NewTicket->new( %{$Self} );
+    $Self->{FollowUpObject}  = Kernel::System::PostMaster::FollowUp->new( %{$Self} );
+    $Self->{RejectObject}    = Kernel::System::PostMaster::Reject->new( %{$Self} );
+
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     # check needed config options
     for my $Option (qw(PostmasterUserID PostmasterX-Header)) {
-        $Self->{$Option} = $Param{ConfigObject}->Get($Option)
+        $Self->{$Option} = $ConfigObject->Get($Option)
             || die "Found no '$Option' option in configuration!";
     }
 
@@ -146,8 +93,11 @@ sub new {
 
     if ( $Self->{Trusted} ) {
 
+        # get dynamic field objects
+        my $DynamicFieldObject = $Kernel::OM->Get('Kernel::System::DynamicField');
+
         # add Dynamic Field headers
-        my $DynamicFields = $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldList(
+        my $DynamicFields = $DynamicFieldObject->DynamicFieldList(
             Valid      => 1,
             ObjectType => [ 'Ticket', 'Article' ],
             ResultType => 'HASH',
@@ -202,29 +152,32 @@ sub Run {
     # check if follow up
     my ( $Tn, $TicketID ) = $Self->CheckFollowUp( %{$GetParam} );
 
+    # get config objects
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     # run all PreFilterModules (modify email params)
-    if ( ref $Self->{ConfigObject}->Get('PostMaster::PreFilterModule') eq 'HASH' ) {
-        my %Jobs = %{ $Self->{ConfigObject}->Get('PostMaster::PreFilterModule') };
+    if ( ref $ConfigObject->Get('PostMaster::PreFilterModule') eq 'HASH' ) {
+
+        my %Jobs = %{ $ConfigObject->Get('PostMaster::PreFilterModule') };
+
+        # get main objects
+        my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
+
+        JOB:
         for my $Job ( sort keys %Jobs ) {
-            return if !$Self->{MainObject}->Require( $Jobs{$Job}->{Module} );
+
+            return if !$MainObject->Require( $Jobs{$Job}->{Module} );
 
             my $FilterObject = $Jobs{$Job}->{Module}->new(
-                EncodeObject => $Self->{EncodeObject},
-                ConfigObject => $Self->{ConfigObject},
-                MainObject   => $Self->{MainObject},
-                LogObject    => $Self->{LogObject},
-                DBObject     => $Self->{DBObject},
-                ParserObject => $Self->{ParserObject},
-                TicketObject => $Self->{TicketObject},
-                TimeObject   => $Self->{TimeObject},
-                Debug        => $Self->{Debug},
+                %{$Self},
             );
+
             if ( !$FilterObject ) {
-                $Self->{LogObject}->Log(
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'error',
                     Message  => "new() of PreFilterModule $Jobs{$Job}->{Module} not successfully!",
                 );
-                next;
+                next JOB;
             }
 
             # modify params
@@ -234,7 +187,7 @@ sub Run {
                 TicketID  => $TicketID,
             );
             if ( !$Run ) {
-                $Self->{LogObject}->Log(
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'error',
                     Message =>
                         "Execute Run() of PreFilterModule $Jobs{$Job}->{Module} not successfully!",
@@ -245,7 +198,7 @@ sub Run {
 
     # should I ignore the incoming mail?
     if ( $GetParam->{'X-OTRS-Ignore'} && $GetParam->{'X-OTRS-Ignore'} =~ /(yes|true)/i ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'info',
             Message =>
                 "Ignored Email (From: $GetParam->{'From'}, Message-ID: $GetParam->{'Message-ID'}) "
@@ -254,39 +207,89 @@ sub Run {
         return (5);
     }
 
-    # ----------------------
+    #
     # ticket section
-    # ----------------------
+    #
 
     # check if follow up (again, with new GetParam)
     ( $Tn, $TicketID ) = $Self->CheckFollowUp( %{$GetParam} );
 
+    # run all PreCreateFilterModules
+    if ( ref $ConfigObject->Get('PostMaster::PreCreateFilterModule') eq 'HASH' ) {
+
+        my %Jobs = %{ $ConfigObject->Get('PostMaster::PreCreateFilterModule') };
+
+        my $LogObject  = $Kernel::OM->Get('Kernel::System::Log');
+        my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
+
+        JOB:
+        for my $Job ( sort keys %Jobs ) {
+
+            return if !$MainObject->Require( $Jobs{$Job}->{Module} );
+
+            my $FilterObject = $Jobs{$Job}->{Module}->new(
+                %{$Self},
+            );
+
+            if ( !$FilterObject ) {
+                $LogObject->Log(
+                    Priority => 'error',
+                    Message  => "new() of PreCreateFilterModule $Jobs{$Job}->{Module} not successfully!",
+                );
+                next JOB;
+            }
+
+            # modify params
+            my $Run = $FilterObject->Run(
+                GetParam  => $GetParam,
+                JobConfig => $Jobs{$Job},
+                TicketID  => $TicketID,
+            );
+            if ( !$Run ) {
+                $LogObject->Log(
+                    Priority => 'error',
+                    Message =>
+                        "Execute Run() of PreCreateFilterModule $Jobs{$Job}->{Module} not successfully!",
+                );
+            }
+        }
+    }
+
     # check if it's a follow up ...
     if ( $Tn && $TicketID ) {
 
+        # get ticket object
+        my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
         # get ticket data
-        my %Ticket = $Self->{TicketObject}->TicketGet(
+        my %Ticket = $TicketObject->TicketGet(
             TicketID      => $TicketID,
             DynamicFields => 0,
         );
 
+        # get queue object
+        my $QueueObject = $Kernel::OM->Get('Kernel::System::Queue');
+
         # check if it is possible to do the follow up
         # get follow up option (possible or not)
-        my $FollowUpPossible = $Self->{QueueObject}->GetFollowUpOption(
+        my $FollowUpPossible = $QueueObject->GetFollowUpOption(
             QueueID => $Ticket{QueueID},
         );
 
         # get lock option (should be the ticket locked - if closed - after the follow up)
-        my $Lock = $Self->{QueueObject}->GetFollowUpLockOption(
+        my $Lock = $QueueObject->GetFollowUpLockOption(
             QueueID => $Ticket{QueueID},
         );
 
         # get state details
-        my %State = $Self->{StateObject}->StateGet( ID => $Ticket{StateID} );
+        my %State = $Kernel::OM->Get('Kernel::System::State')->StateGet(
+            ID => $Ticket{StateID},
+        );
 
         # create a new ticket
-        if ( $FollowUpPossible =~ /new ticket/i && $State{TypeName} =~ /^close/i ) {
-            $Self->{LogObject}->Log(
+        if ( $FollowUpPossible =~ /new ticket/i && $State{TypeName} =~ /^(removed|close)/i ) {
+
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'info',
                 Message  => "Follow up for [$Tn] but follow up not possible ($Ticket{State})."
                     . " Create new ticket."
@@ -311,13 +314,13 @@ sub Run {
             # Clean out the old TicketNumber from the subject (see bug#9108).
             # This avoids false ticket number detection on customer replies.
             if ( $GetParam->{Subject} ) {
-                $GetParam->{Subject} = $Self->{TicketObject}->TicketSubjectClean(
+                $GetParam->{Subject} = $TicketObject->TicketSubjectClean(
                     TicketNumber => $Tn,
                     Subject      => $GetParam->{Subject},
                 );
             }
 
-            $TicketID = $Self->{NewTicket}->Run(
+            $TicketID = $Self->{NewTicketObject}->Run(
                 InmailUserID     => $Self->{PostmasterUserID},
                 GetParam         => $GetParam,
                 QueueID          => $Param{QueueID},
@@ -325,21 +328,24 @@ sub Run {
                 AutoResponseType => 'auto reply/new ticket',
                 LinkToTicketID   => $TicketID,
             );
+
             if ( !$TicketID ) {
                 return;
             }
+
             @Return = ( 3, $TicketID );
         }
 
         # reject follow up
-        elsif ( $FollowUpPossible =~ /reject/i && $State{TypeName} =~ /^close/i ) {
-            $Self->{LogObject}->Log(
+        elsif ( $FollowUpPossible =~ /reject/i && $State{TypeName} =~ /^(removed|close)/i ) {
+
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'info',
                 Message  => "Follow up for [$Tn] but follow up not possible. Follow up rejected."
             );
 
             # send reject mail && and add article to ticket
-            my $Run = $Self->{Reject}->Run(
+            my $Run = $Self->{RejectObject}->Run(
                 TicketID         => $TicketID,
                 InmailUserID     => $Self->{PostmasterUserID},
                 GetParam         => $GetParam,
@@ -348,15 +354,18 @@ sub Run {
                 Comment          => 'Follow up rejected.',
                 AutoResponseType => 'auto reject',
             );
+
             if ( !$Run ) {
                 return;
             }
+
             @Return = ( 4, $TicketID );
         }
 
         # create normal follow up
         else {
-            my $Run = $Self->{FollowUp}->Run(
+
+            my $Run = $Self->{FollowUpObject}->Run(
                 TicketID         => $TicketID,
                 InmailUserID     => $Self->{PostmasterUserID},
                 GetParam         => $GetParam,
@@ -364,19 +373,24 @@ sub Run {
                 Tn               => $Tn,
                 AutoResponseType => 'auto follow up',
             );
+
             if ( !$Run ) {
                 return;
             }
+
             @Return = ( 2, $TicketID );
         }
     }
 
     # create new ticket
     else {
+
         if ( $Param{Queue} && !$Param{QueueID} ) {
 
             # queue lookup if queue name is given
-            $Param{QueueID} = $Self->{QueueObject}->QueueLookup( Queue => $Param{Queue} );
+            $Param{QueueID} = $Kernel::OM->Get('Kernel::System::Queue')->QueueLookup(
+                Queue => $Param{Queue},
+            );
         }
 
         # get queue if of From: and To:
@@ -391,39 +405,41 @@ sub Run {
         if ($TQueueID) {
             $Param{QueueID} = $TQueueID;
         }
-        $TicketID = $Self->{NewTicket}->Run(
+        $TicketID = $Self->{NewTicketObject}->Run(
             InmailUserID     => $Self->{PostmasterUserID},
             GetParam         => $GetParam,
             QueueID          => $Param{QueueID},
             AutoResponseType => 'auto reply',
         );
+
         return if !$TicketID;
+
         @Return = ( 1, $TicketID );
     }
 
     # run all PostFilterModules (modify email params)
-    if ( ref $Self->{ConfigObject}->Get('PostMaster::PostFilterModule') eq 'HASH' ) {
-        my %Jobs = %{ $Self->{ConfigObject}->Get('PostMaster::PostFilterModule') };
+    if ( ref $ConfigObject->Get('PostMaster::PostFilterModule') eq 'HASH' ) {
+
+        my %Jobs = %{ $ConfigObject->Get('PostMaster::PostFilterModule') };
+
+        # get main objects
+        my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
+
+        JOB:
         for my $Job ( sort keys %Jobs ) {
-            return if !$Self->{MainObject}->Require( $Jobs{$Job}->{Module} );
+
+            return if !$MainObject->Require( $Jobs{$Job}->{Module} );
 
             my $FilterObject = $Jobs{$Job}->{Module}->new(
-                EncodeObject => $Self->{EncodeObject},
-                ConfigObject => $Self->{ConfigObject},
-                MainObject   => $Self->{MainObject},
-                LogObject    => $Self->{LogObject},
-                DBObject     => $Self->{DBObject},
-                ParserObject => $Self->{ParserObject},
-                TicketObject => $Self->{TicketObject},
-                TimeObject   => $Self->{TimeObject},
-                Debug        => $Self->{Debug},
+                %{$Self},
             );
+
             if ( !$FilterObject ) {
-                $Self->{LogObject}->Log(
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'error',
                     Message  => "new() of PostFilterModule $Jobs{$Job}->{Module} not successfully!",
                 );
-                next;
+                next JOB;
             }
 
             # modify params
@@ -432,8 +448,9 @@ sub Run {
                 GetParam  => $GetParam,
                 JobConfig => $Jobs{$Job},
             );
+
             if ( !$Run ) {
-                $Self->{LogObject}->Log(
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'error',
                     Message =>
                         "Execute Run() of PostFilterModule $Jobs{$Job}->{Module} not successfully!",
@@ -441,6 +458,7 @@ sub Run {
             }
         }
     }
+
     return @Return;
 }
 
@@ -457,40 +475,56 @@ to detect the ticket number in processing email
 sub CheckFollowUp {
     my ( $Self, %Param ) = @_;
 
+    # get ticket object
+    my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
     my $Subject = $Param{Subject} || '';
-    my $Tn = $Self->{TicketObject}->GetTNByString($Subject);
+    my $Tn = $TicketObject->GetTNByString($Subject);
 
     if ($Tn) {
-        my $TicketID = $Self->{TicketObject}->TicketCheckNumber( Tn => $Tn );
+
+        my $TicketID = $TicketObject->TicketCheckNumber( Tn => $Tn );
+
         return if !$TicketID;
 
-        my %Ticket = $Self->{TicketObject}->TicketGet(
+        my %Ticket = $TicketObject->TicketGet(
             TicketID      => $TicketID,
             DynamicFields => 0,
         );
+
         if ( $Self->{Debug} > 1 ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'debug',
                 Message  => "CheckFollowUp: ja, it's a follow up ($Ticket{TicketNumber}/$TicketID)",
             );
         }
+
         return ( $Ticket{TicketNumber}, $TicketID );
     }
 
+    # get config objects
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     # There is no valid ticket number in the subject.
     # Try to find ticket number in References and In-Reply-To header.
-    if ( $Self->{ConfigObject}->Get('PostmasterFollowUpSearchInReferences') ) {
+    if ( $ConfigObject->Get('PostmasterFollowUpSearchInReferences') ) {
+
         my @References = $Self->{ParserObject}->GetReferences();
+
+        REFERENCE:
         for my $Reference (@References) {
 
             # get ticket id of message id
-            my $TicketID = $Self->{TicketObject}->ArticleGetTicketIDOfMessageID(
+            my $TicketID = $TicketObject->ArticleGetTicketIDOfMessageID(
                 MessageID => "<$Reference>",
             );
-            next if !$TicketID;
-            my $Tn = $Self->{TicketObject}->TicketNumberLookup(
+
+            next REFERENCE if !$TicketID;
+
+            my $Tn = $TicketObject->TicketNumberLookup(
                 TicketID => $TicketID,
             );
+
             if ( $TicketID && $Tn ) {
                 return ( $Tn, $TicketID );
             }
@@ -498,45 +532,60 @@ sub CheckFollowUp {
     }
 
     # do body ticket number lookup
-    if ( $Self->{ConfigObject}->Get('PostmasterFollowUpSearchInBody') ) {
-        my $Tn = $Self->{TicketObject}->GetTNByString( $Self->{ParserObject}->GetMessageBody() );
+    if ( $ConfigObject->Get('PostmasterFollowUpSearchInBody') ) {
+
+        my $Tn = $TicketObject->GetTNByString( $Self->{ParserObject}->GetMessageBody() );
+
         if ($Tn) {
-            my $TicketID = $Self->{TicketObject}->TicketCheckNumber( Tn => $Tn );
+
+            my $TicketID = $TicketObject->TicketCheckNumber( Tn => $Tn );
+
             if ($TicketID) {
-                my %Ticket = $Self->{TicketObject}->TicketGet(
+
+                my %Ticket = $TicketObject->TicketGet(
                     TicketID      => $TicketID,
                     DynamicFields => 0,
                 );
+
                 if ( $Self->{Debug} > 1 ) {
-                    $Self->{LogObject}->Log(
+                    $Kernel::OM->Get('Kernel::System::Log')->Log(
                         Priority => 'debug',
                         Message =>
                             "CheckFollowUp (in body): ja, it's a follow up ($Ticket{TicketNumber}/$TicketID)",
                     );
                 }
+
                 return ( $Ticket{TicketNumber}, $TicketID );
             }
         }
     }
 
     # do attachment ticket number lookup
-    if ( $Self->{ConfigObject}->Get('PostmasterFollowUpSearchInAttachment') ) {
+    if ( $ConfigObject->Get('PostmasterFollowUpSearchInAttachment') ) {
+
         for my $Attachment ( $Self->{ParserObject}->GetAttachments() ) {
-            my $Tn = $Self->{TicketObject}->GetTNByString( $Attachment->{Content} );
+
+            my $Tn = $TicketObject->GetTNByString( $Attachment->{Content} );
+
             if ($Tn) {
-                my $TicketID = $Self->{TicketObject}->TicketCheckNumber( Tn => $Tn );
+
+                my $TicketID = $TicketObject->TicketCheckNumber( Tn => $Tn );
+
                 if ($TicketID) {
-                    my %Ticket = $Self->{TicketObject}->TicketGet(
+
+                    my %Ticket = $TicketObject->TicketGet(
                         TicketID      => $TicketID,
                         DynamicFields => 0,
                     );
+
                     if ( $Self->{Debug} > 1 ) {
-                        $Self->{LogObject}->Log(
+                        $Kernel::OM->Get('Kernel::System::Log')->Log(
                             Priority => 'debug',
                             Message =>
                                 "CheckFollowUp (in attachment): ja, it's a follow up ($Ticket{TicketNumber}/$TicketID)",
                         );
                     }
+
                     return ( $Ticket{TicketNumber}, $TicketID );
                 }
             }
@@ -544,26 +593,34 @@ sub CheckFollowUp {
     }
 
     # do plain/raw ticket number lookup
-    if ( $Self->{ConfigObject}->Get('PostmasterFollowUpSearchInRaw') ) {
-        my $Tn = $Self->{TicketObject}->GetTNByString( $Self->{ParserObject}->GetPlainEmail() );
+    if ( $ConfigObject->Get('PostmasterFollowUpSearchInRaw') ) {
+
+        my $Tn = $TicketObject->GetTNByString( $Self->{ParserObject}->GetPlainEmail() );
+
         if ($Tn) {
-            my $TicketID = $Self->{TicketObject}->TicketCheckNumber( Tn => $Tn );
+
+            my $TicketID = $TicketObject->TicketCheckNumber( Tn => $Tn );
+
             if ($TicketID) {
-                my %Ticket = $Self->{TicketObject}->TicketGet(
+
+                my %Ticket = $TicketObject->TicketGet(
                     TicketID      => $TicketID,
                     DynamicFields => 0,
                 );
+
                 if ( $Self->{Debug} > 1 ) {
-                    $Self->{LogObject}->Log(
+                    $Kernel::OM->Get('Kernel::System::Log')->Log(
                         Priority => 'debug',
                         Message =>
                             "CheckFollowUp (in plain/raw): ja, it's a follow up ($Ticket{TicketNumber}/$TicketID)",
                     );
                 }
+
                 return ( $Ticket{TicketNumber}, $TicketID );
             }
         }
     }
+
     return;
 }
 
@@ -587,7 +644,7 @@ sub GetEmailParams {
         # do not scan x-otrs headers if mailbox is not marked as trusted
         next HEADER if ( !$Self->{Trusted} && $Param =~ /^x-otrs/i );
         if ( $Self->{Debug} > 2 ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'debug',
                 Message  => "$Param: " . $Self->{ParserObject}->GetParam( WHAT => $Param ),
             );
@@ -629,15 +686,19 @@ sub GetEmailParams {
         }
     }
 
+    # get ticket object
+    my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
     # set sender type if not given
     for my $Key (qw(X-OTRS-SenderType X-OTRS-FollowUp-SenderType)) {
+
         if ( !$GetParam{$Key} ) {
             $GetParam{$Key} = 'customer';
         }
 
         # check if X-OTRS-SenderType exists, if not, set customer
-        if ( !$Self->{TicketObject}->ArticleSenderTypeLookup( SenderType => $GetParam{$Key} ) ) {
-            $Self->{LogObject}->Log(
+        if ( !$TicketObject->ArticleSenderTypeLookup( SenderType => $GetParam{$Key} ) ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Can't find sender type '$GetParam{$Key}' in db, take 'customer'",
             );
@@ -652,8 +713,8 @@ sub GetEmailParams {
         }
 
         # check if X-OTRS-ArticleType exists, if not, set 'email'
-        if ( !$Self->{TicketObject}->ArticleTypeLookup( ArticleType => $GetParam{$Key} ) ) {
-            $Self->{LogObject}->Log(
+        if ( !$TicketObject->ArticleTypeLookup( ArticleType => $GetParam{$Key} ) ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Can't find article type '$GetParam{$Key}' in db, take 'email-external'",
             );
@@ -672,7 +733,6 @@ sub GetEmailParams {
     my @Attachments = $Self->{ParserObject}->GetAttachments();
     $GetParam{Attachment} = \@Attachments;
 
-    # return params
     return \%GetParam;
 }
 
@@ -682,10 +742,10 @@ sub GetEmailParams {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<http://otrs.org/>).
+This software is part of the OTRS project (L<https://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
 
 =cut
