@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::System::SupportDataCollector::PluginAsynchronous::OTRS::ConcurrentUsers;
@@ -25,7 +25,8 @@ our @ObjectDependencies = (
 );
 
 sub GetDisplayPath {
-    return 'OTRS@Table:TimeStamp,UserSessionUnique|Unique agents,UserSession|Agent sessions,CustomerSessionUnique|Unique customers,CustomerSession|Customer sessions';
+    return
+        'OTRS@Table:TimeStamp,UserSessionUnique|Unique agents,UserSession|Agent sessions,CustomerSessionUnique|Unique customers,CustomerSession|Customer sessions';
 }
 
 sub Run {
@@ -35,8 +36,8 @@ sub Run {
 
     # the table details data
     $Self->AddResultInformation(
-        Label      => 'Concurrent Users Details',
-        Value      => $ConcurrentUsers || [],
+        Label => 'Concurrent Users Details',
+        Value => $ConcurrentUsers || [],
     );
 
     # get the full display path
@@ -64,9 +65,10 @@ sub Run {
         my $MaxValue = 0;
 
         ENTRY:
-        for my $Entry (@{$ConcurrentUsers}) {
+        for my $Entry ( @{$ConcurrentUsers} ) {
 
-            next ENTRY if $Entry->{$Identifier} le $MaxValue;
+            next ENTRY if !$Entry->{$Identifier};
+            next ENTRY if $Entry->{$Identifier} <= $MaxValue;
 
             $MaxValue = $Entry->{$Identifier};
         }
@@ -92,7 +94,7 @@ sub RunAsynchronous {
     my $SystemTimeNow = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
 
     my ( $Sec, $Min, $Hour, $Day, $Month, $Year, $WeekDay ) = $TimeObject->SystemTime2Date(
-        SystemTime => $SystemTimeNow,
+        SystemTime => $SystemTimeNow + 3600,
     );
 
     my $SystemTime = $TimeObject->Date2SystemTime(
@@ -110,19 +112,24 @@ sub RunAsynchronous {
 
     my $AsynchronousData = $Self->_GetAsynchronousData();
 
-    my $TimeStampExists;
+    my $CurrentHourPosition;
 
     if ( IsArrayRefWithData($AsynchronousData) ) {
 
+        # already existing entry counter
+        my $AsynchronousDataCount = scalar @{$AsynchronousData} - 1;
+
         # check if for the current hour already a value exists
-        ENTRY:
-        for my $Entry ( reverse @{$AsynchronousData} ) {
+        COUNTER:
+        for my $Counter ( 0 .. $AsynchronousDataCount ) {
 
-            next ENTRY if $Entry->{TimeStamp} && $Entry->{TimeStamp} ne $TimeStamp;
+            next COUNTER
+                if $AsynchronousData->[$Counter]->{TimeStamp}
+                && $AsynchronousData->[$Counter]->{TimeStamp} ne $TimeStamp;
 
-            $TimeStampExists = 1;
+            $CurrentHourPosition = $Counter;
 
-            last ENTRY;
+            last COUNTER;
         }
 
         # set the check timestamp to one week ago
@@ -143,14 +150,6 @@ sub RunAsynchronous {
 
         # remove all entries older than one week
         @{$AsynchronousData} = grep { $_->{TimeStamp} && $_->{TimeStamp} ge $CheckTimeStamp } @{$AsynchronousData};
-
-        if ($TimeStampExists) {
-
-            $Self->_StoreAsynchronousData(
-                Data => $AsynchronousData,
-            );
-            return 1;
-        }
     }
 
     # get AuthSession object
@@ -164,12 +163,6 @@ sub RunAsynchronous {
         }
     }
 
-    # get the session active time
-    my $SessionActiveTime = $Kernel::OM->Get('Kernel::Config')->Get('SessionActiveTime') || 60 * 10;
-
-    # get all sessions
-    my @Sessions = $AuthSessionObject->GetAllSessionIDs();
-
     # to count the agents and customer user sessions
     my %CountConcurrentUser = (
         TimeStamp             => $TimeStamp,
@@ -179,47 +172,37 @@ sub RunAsynchronous {
         CustomerSessionUnique => 0,
     );
 
-    # to save the unique agents and customer users
-    my %LookupUsers;
-    my %LookupCustomers;
+    for my $UserType (qw(User Customer)) {
 
-    # collect the existing sessions of each user (not customer user)
-    SESSION:
-    for my $SessionID (@Sessions) {
+        my %ActiveSessions = $AuthSessionObject->GetActiveSessions(
+            UserType => $UserType,
+        );
 
-        # get session data
-        my %SessionData = $AuthSessionObject->GetSessionIDData( SessionID => $SessionID );
-
-        next SESSION if !%SessionData;
-
-        # get needed data
-        my $UserType        = $SessionData{UserType}        || '';
-        my $UserLastRequest = $SessionData{UserLastRequest} || $SystemTimeNow;
-        my $UserLogin       = $SessionData{UserLogin};
-
-        next SESSION if $UserType ne 'User' && $UserType ne 'Customer';
-        next SESSION if ( $UserLastRequest + $SessionActiveTime ) < $SystemTimeNow;
-
-        $CountConcurrentUser{ $UserType . 'Session' }++;
-
-        if ( $UserType eq 'User' ) {
-
-            if ( !$LookupUsers{$UserLogin} ) {
-                $CountConcurrentUser{UserSessionUnique}++;
-                $LookupUsers{$UserLogin} = 1;
-            }
-        }
-        elsif ( $UserType eq 'Customer' ) {
-
-            if ( !$LookupCustomers{$UserLogin} ) {
-                $CountConcurrentUser{CustomerSessionUnique}++;
-                $LookupCustomers{$UserLogin} = 1;
-            }
-        }
+        $CountConcurrentUser{ $UserType . 'Session' }       = $ActiveSessions{Total};
+        $CountConcurrentUser{ $UserType . 'SessionUnique' } = scalar keys %{ $ActiveSessions{PerUser} };
     }
 
-    # add the new entry to the AsynchronousData
-    push @{$AsynchronousData}, \%CountConcurrentUser;
+    # update the concurrent user counter, if a higher value for the current hour exists
+    if ( defined $CurrentHourPosition ) {
+
+        my $ChangedConcurrentUserCounter;
+
+        IDENTIFIER:
+        for my $Identifier (qw(UserSessionUnique UserSession CustomerSession CustomerSessionUnique)) {
+
+            next IDENTIFIER
+                if $AsynchronousData->[$CurrentHourPosition]->{$Identifier} >= $CountConcurrentUser{$Identifier};
+
+            $AsynchronousData->[$CurrentHourPosition]->{$Identifier} = $CountConcurrentUser{$Identifier};
+
+            $ChangedConcurrentUserCounter = 1;
+        }
+
+        return 1 if !$ChangedConcurrentUserCounter;
+    }
+    else {
+        push @{$AsynchronousData}, \%CountConcurrentUser;
+    }
 
     $Self->_StoreAsynchronousData(
         Data => $AsynchronousData,
@@ -232,11 +215,11 @@ sub RunAsynchronous {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<http://otrs.org/>).
+This software is part of the OTRS project (L<https://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
 
 =cut
 
